pyimagediet
===========

pyimagediet is a MIT licensed Python wrapper around image optimisations tools
used to reduce images size without loss of visual quality. It provides
a uniform interface to tools, easy configuration and integration.

It works on images in JPEG, GIF, PNG or really any format for which you have
optimisations tools.


**Documentation:**

.. image:: https://readthedocs.org/projects/pyimagediet/badge/?version=latest
  :target: http://pyimagediet.readthedocs.org/en/latest/?badge=latest
  :alt: Documentation Status

**Tests:**

.. image:: https://coveralls.io/repos/samastur/pyimagediet/badge.svg?branch=master&service=github
  :target: https://coveralls.io/github/samastur/pyimagediet?branch=master 

.. image:: https://travis-ci.org/samastur/pyimagediet.svg?branch=master
  :target: https://travis-ci.org/samastur/pyimagediet

**Build:**

.. image:: https://requires.io/github/samastur/pyimagediet/requirements.svg?branch=master
  :target: https://requires.io/github/samastur/pyimagediet/requirements/?branch=master
  :alt: Requirements Status

`Documentation <http://pyimagediet.readthedocs.org/en/latest/>`_
